# Spruce

Acacia is a program that lets you generate simple and concise presentations, as all presentations should be.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install Acacia
```

## Usage

```bash
Acacia yourfile.txt
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[GPL](https://choosealicense.com/licenses/gpl-3.0/)